import unittest

from air_pack_test import AirPackTest
from airquality_pack_test import AirQualityPackTest
from astronomy_pack_test import AstronomyPackTest
from geo_pack_test import GeoPackTest
from grid_weather_pack_test import GridWeatherPackTest
from indices_pack_test import IndicesPackTest
from minutely_pack_test import MinutelyPackTest
from ocean_pack_test import OceanPackTest
from solar_radiation_pack_test import SolarRadiationPackTest
from time_machine_pack_test import TimeMachinePackTest
from tropical_cyclone_pack_test import TropicalCyclonePackTest
from weather_pack_test import WeatherPackTest
from weather_warning_pack_test import WeatherWarningPackTest


if __name__ == '__main__':
  
  unittest.main(verbosity=2)



from pyqweather import QWeatherRequestBase, QWeatherResponseBase
from pyqweather.packages import QWeatherAirDailyDto
from dataclasses import dataclass


class AirDailyRequest(QWeatherRequestBase):
  
  _PATH = '/air'
  
  def __init__(self, day_range:str, **kwargs):
    super().__init__(**kwargs)
    self.location = self.get_arg('location', kwargs, required=True)
    self.lang = self.get_arg('lang', kwargs)
    self._PATH = f'/air/{day_range}'
    
    
  def __str__(self) -> str:
    return f'location={self.location}'
  
@dataclass
class AirDailyResponse(QWeatherResponseBase):
  
  updateTime: str
  fxLink: str
  daily:list[QWeatherAirDailyDto]
  
  
  def __init__(self, **kwargs):
    super().__init__(**kwargs)
    self.updateTime = self.get_arg('updateTime', kwargs, None)
    self.fxLink = self.get_arg('fxLink', kwargs, None)
    self.daily:list[QWeatherAirDailyDto] = self.get_items('daily', kwargs, QWeatherAirDailyDto)
    



from pyqweather import QWeatherRequestBase, QWeatherResponseBase
from pyqweather.packages import QWeatherIndicesDailyDto
from dataclasses import dataclass


class IndicesDailyRequest(QWeatherRequestBase):

  _PATH = '/indices'

  def __init__(self, day_range: str, **kwargs):
    super().__init__(**kwargs)
    self._PATH = f'/indices/{day_range}'
    self.location = self.get_arg('location', kwargs, required=True)
    self.lang = self.get_arg('lang', kwargs)
    self.type = self.get_arg('type', kwargs, required=True)

  def __str__(self) -> str:
    return f'location={self.location}'

@dataclass
class IndicesDailyResponse(QWeatherResponseBase):

  updateTime: str
  fxLink: str
  daily: list[QWeatherIndicesDailyDto]


  def __init__(self, **kwargs):
    super().__init__(**kwargs)
    self.updateTime = self.get_arg('updateTime', kwargs, None)
    self.fxLink = self.get_arg('fxLink', kwargs, None)
    self.daily:list[QWeatherIndicesDailyDto] = self.get_items('daily', kwargs, QWeatherIndicesDailyDto)
    



from pyqweather import QWeatherRequestBase, QWeatherResponseBase
from pyqweather.packages import QWeatherSimpleAirHourlyDto
from dataclasses import dataclass

class HistoricalAirRequest(QWeatherRequestBase):
  
  _PATH = '/historical/air'
  
  def __init__(self, **kwargs):
    super().__init__(**kwargs)
    self.location = self.get_arg('location', kwargs, required=True)
    self.date = self.get_arg('date', kwargs, required=True)
    self.lang = self.get_arg('lang', kwargs)
    
    
  def __str__(self) -> str:
    return f'location={self.location}'
  
@dataclass
class HistoricalAirResponse(QWeatherResponseBase):
  
  fxLink: str
  airHourly:list[QWeatherSimpleAirHourlyDto]
  
  def __init__(self, **kwargs):
    super().__init__(**kwargs)
    self.fxLink = self.get_arg('fxLink', kwargs, None)
    self.airHourly:list[QWeatherSimpleAirHourlyDto] = self.get_items('airHourly', kwargs, QWeatherSimpleAirHourlyDto)
    



from pyqweather import QWeatherRequestBase, QWeatherResponseBase
from dataclasses import dataclass


class AstronomySolarElevationAngleRequest(QWeatherRequestBase):

    _PATH = '/astronomy/solar-elevation-angle'

    def __init__(self, **kwargs):

        super().__init__(**kwargs)
        self.location = self.get_arg('location', kwargs, required=True)
        self.date = self.get_arg('date', kwargs, required=True)
        self.time = self.get_arg('time', kwargs, required=True)
        self.tz = self.get_arg('tz', kwargs, required=True)
        self.alt = self.get_arg('alt', kwargs, required=True)

    def __str__(self) -> str:
        return f'location={self.location}'


@dataclass
class AstronomySolarElevationAngleResponse(QWeatherResponseBase):

    updateTime: str
    solarElevationAngle: str
    solarAzimuthAngle: str
    solarHour: str
    hourAngle: str

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.updateTime = self.get_arg('updateTime', kwargs, None)
        self.solarElevationAngle = self.get_arg(
            'solarElevationAngle', kwargs, None)
        self.solarAzimuthAngle = self.get_arg(
            'solarAzimuthAngle', kwargs, None)
        self.solarHour = self.get_arg('solarHour', kwargs, None)
        self.hourAngle = self.get_arg('hourAngle', kwargs, None)




from pyqweather import QWeatherRequestBase, QWeatherResponseBase
from pyqweather.packages import QWeatherMoonPhaseDto
from dataclasses import dataclass


class AstronomyMoonRequest(QWeatherRequestBase):

    _PATH = '/astronomy/moon'

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.location = self.get_arg('location', kwargs, required=True)
        self.date = self.get_arg('date', kwargs, required=True)
        self.lang = self.get_arg('lang', kwargs)

    def __str__(self) -> str:
        return f'location={self.location}'

@dataclass
class AstronomyMoonResponse(QWeatherResponseBase):

    updateTime: str
    fxLink: str
    moonrise: str
    moonset: str
    moonPhase: list[QWeatherMoonPhaseDto]

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.updateTime = self.get_arg('updateTime', kwargs, None)
        self.fxLink = self.get_arg('fxLink', kwargs, None)
        self.moonrise = self.get_arg('sunrise', kwargs, None)
        self.moonset = self.get_arg('sunset', kwargs, None)
        self.moonPhase: list[QWeatherMoonPhaseDto] = self.get_items(
            'moonPhase', kwargs, QWeatherMoonPhaseDto)




from pyqweather import QWeatherRequestBase, QWeatherResponseBase
from pyqweather.packages import QWeatherMinutelyRainDataDto
from dataclasses import dataclass


class Minutely5mRequest(QWeatherRequestBase):

    _PATH = '/minutely/5m'

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.location = self.get_arg('location', kwargs, required=True)
        self.lang = self.get_arg('lang', kwargs)

    def __str__(self) -> str:
        return f'location={self.location}'


@dataclass
class Minutely5mResponse(QWeatherResponseBase):

    updateTime: str
    fxLink: str
    minutely: list[QWeatherMinutelyRainDataDto]
    summary: str

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.updateTime = self.get_arg('updateTime', kwargs, None)
        self.fxLink = self.get_arg('fxLink', kwargs, None)
        self.minutely: list[QWeatherMinutelyRainDataDto] = self.get_items(
            'minutely', kwargs, QWeatherMinutelyRainDataDto)
        self.summary = self.get_arg('summary', kwargs, None)




from pyqweather import QWeatherRequestBase, QWeatherResponseBase
from pyqweather.packages import QWeatherWeatherDailyDataDto
from dataclasses import dataclass


class GridWeatherDailyRequest(QWeatherRequestBase):

    _PATH = '/grid-weather'

    def __init__(self, day_range: str, **kwargs):
        super().__init__(**kwargs)
        self._PATH = f'/grid-weather/{day_range}'
        self.location = self.get_arg('location', kwargs, required=True)
        self.lang = self.get_arg('lang', kwargs)
        self.unit = self.get_arg('unit', kwargs)

    def __str__(self) -> str:
        return f'location={self.location}'


@dataclass
class GridWeatherDailyResponse(QWeatherResponseBase):

    updateTime: str
    fxLink: str
    daily: list[QWeatherWeatherDailyDataDto]

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.updateTime = self.get_arg('updateTime', kwargs, None)
        self.fxLink = self.get_arg('fxLink', kwargs, None)
        self.daily: list[QWeatherWeatherDailyDataDto] = self.get_items(
            'daily', kwargs, QWeatherWeatherDailyDataDto)
